Stan Math Library: stan/math/prim/mat/fun/rows.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

rows.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_ROWS_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_ROWS_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5
6 namespace stan {
7 namespace math {
8
19 template <typename T, int R, int C>
20 inline int rows(const Eigen::Matrix<T, R, C>& m) {
21 return m.rows();
22 }
23
24 }
25 }
26 #endif
stan::math::rows
int rows(const Eigen::Matrix< T, R, C > &m)
Return the number of rows in the specified matrix, vector, or row vector.
Definition: rows.hpp:20
stan
Definition: log_sum_exp.hpp:8
Eigen.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.